Welcome to rpl-pack’s documentation! — rpl-pack 0.0.1 documentation

# Welcome to rpl-pack’s documentation!

rpl-pack is a Python library for interfacing with the RPL Server and offers a simple and intuitive API for all your rock physics needs!

Check out the Quick Start section for further information, including how to install the project.

Note

This project is under active development and the API is not currently stable. Therefore, we cannot guarantee that, as development continues, the API will be back-compatible with each new release. However, we will make an active effort to warn of any deprecated features, syntax, or otherwise ahead of the scheduled update. Feel free to contact us with any questions or concerns.

# Indices and tables

- Index

- Module Index

- Search Page